//
//  KWSCallbacks.h
//  KonyWebSocket
//
//  Created by Sai Sanjeev on 1/1/2020.
//  Copyright © 2020 Kony. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

typedef enum
{
    onMessage = 0,
    onError,
    onClose,
    onPublish,
    onSubscribe,
    onUnsubscribe
} CallbackType;

/**
 * Method to be implemented for handling on message callback
 *
 * @param result object representing the result
 */
typedef void (^onMessageCallback) (NSString* result);

/**
 * Method to be implemented for handling on error callback
 *
 * @param error object representing the error(s)
 */
typedef void (^onErrorCallback) (NSString* error);

/**
 * Method to be implemented for handling on close callback
 *
 * @param result object representing the result
 */
typedef void (^onCloseCallback) (NSString* result);

/**
 * Method to be implemented for handling on subscribe callback
 *
 * @param result object representing the result
 */
typedef void (^onSubscribeCallback) (NSString* result);

/**
* Method to be implemented for handling on publish callback
*
* @param result object representing the result
*/
typedef void (^onPublishCallback) (NSString* result);

/**
* Method to be implemented for handling on unsubscribe callback
*
* @param result object representing the result
*/
typedef void (^onUnsubscribeCallback) (NSString* result);

@interface KWSCallbacks : NSObject

- (id) init __attribute__((unavailable("Must use sharedInstance instead.")));

+ (instancetype) getSharedInstance;

- (void) setOnMessageCallback: (onMessageCallback)onMessageCallback;

- (void) setOnErrorCallback: (onErrorCallback)onErrorCallback;

- (void) setOnCloseCallback: (onCloseCallback)onCloseCallback;

- (void) setOnSubscribeCallback: (onSubscribeCallback)onSubscribeCallback;

- (void) setOnUnsubscribeCallback: (onUnsubscribeCallback)onUnsubscribeCallback;

- (void) setOnPublishCallback: (onPublishCallback)onPublishCallback;

- (void) executeWithCallback: (CallbackType)callbackType result: (id)result;

@end

NS_ASSUME_NONNULL_END
