//
//  IKonyWebSocket.h
//  KonyWebSocket
//
//  Created by Sai Sanjeev on 1/1/2020.
//  Copyright © 2020 Kony. All rights reserved.
//

#import <SocketRocket/SocketRocket.h>

#import "KWSCallbacks.h"

@interface KonyWebSocket : NSObject

- (instancetype) init;

- (void) setServerEventsCallbacks : (onMessageCallback) onMessage
                           onError: (onErrorCallback) onError
                           onClose: (onCloseCallback) onClose;
/**
 Subscribe for server events
 
 @param eventsJson                eventsJson string to be published to the server
 
 example :
 "{"subscribe" : ["transaction/deposit",
 "transaction/withdraw"]}"
 
 @param subscribeOptions  additional options for subscribing - NSDictionary
 */
- (void) subscribeServerEvents: (NSString *) url
                        events: (NSString *) eventsJson
                   onSubscribe: (onSubscribeCallback) onSubscribe
              subscribeOptions: (NSDictionary *) subscribeOptions;

/**
 UnSubscribe from server events
 
 @param eventsJson                    eventsJson string to unsubscribe - NSString
 example :
 "{"unsubscribe" : ["transaction/deposit"]}"
 
 @param unSubscribeOptions   additional options to unsubscribe - NSDictionary
 */
- (void) unSubscribeServerEvents: (NSString *) eventsJson
                   onUnsubscribe: (onUnsubscribeCallback) onUnsubscribe
              unSubscribeOptions: (NSDictionary *) unSubscribeOptions;

// Supressing Publish Api.
///**
// Publish events to the server
// @param eventsJson           eventsJson string to be published to the server - NSString
// example :
// "{"events" : [{"topic" : "transaction/deposit",
// "data" : { "amount": "1500",
// "user": "clientevents",
// "account": "1000",
// "transaction": "deposit" }}]}"
// @param publishOptions  additional options for publishing - NSDictionary
// */
//- (void) publishServerEvents: (NSString *) eventsJson
//                   onPublish: (onPublishCallback) onPublish
//              publishOptions: (NSDictionary *) publishOptions;

/**
 Checks and returns if websocket instance is available
 */
- (BOOL) isWebSocketAvailable;

@end
